@@ -18,8 +18,6 @@
 
 #include "config.h"
 
-#include <new>
-
 #include <QtGlobal>
 #include <QAction>
 #include <QIcon>
@@ -37,6 +35,8 @@
 #include "FileContext.h"
 #include "PlayerToolBar.h"
 
+using namespace Qt::Literals::StringLiterals;
+
 /** default width to skip when doing a "seek" = 1/10 of visible range */
 #define SEEK_LENGTH (m_last_visible / 10)
 
@@ -52,19 +52,17 @@
 Kwave::PlayerToolBar::PlayerToolBar(KMainWindow *parent, const QString &name,
                                     Kwave::MenuManager &menu_manager)
     :KToolBar(name, parent, true),
-     m_context(Q_NULLPTR),
-     m_action_prev(),
-     m_action_rewind(Q_NULLPTR),
-     m_action_record(Q_NULLPTR),
-     m_action_play(Q_NULLPTR),
-     m_action_loop(Q_NULLPTR),
-     m_action_pause(Q_NULLPTR),
-     m_action_stop(Q_NULLPTR),
-     m_action_forward(Q_NULLPTR),
-     m_action_next(Q_NULLPTR),
-     m_pause_timer(Q_NULLPTR),
-     m_blink_on(false),
-     m_playback(Q_NULLPTR),
+     m_context(nullptr),
+     m_action_prev(nullptr),
+     m_action_rewind(nullptr),
+     m_action_record(nullptr),
+     m_action_play(nullptr),
+     m_action_loop(nullptr),
+     m_action_pause(nullptr),
+     m_action_stop(nullptr),
+     m_action_forward(nullptr),
+     m_action_next(nullptr),
+     m_playback(nullptr),
      m_menu_manager(menu_manager),
      m_labels(),
      m_last_tracks(0),
@@ -72,50 +70,51 @@ Kwave::PlayerToolBar::PlayerToolBar(KMainWindow *parent, const QString &name,
      m_last_visible(0),
      m_last_length(0)
 {
-    m_action_prev = addAction(
-        QIcon::fromTheme(_("kwave_player_start")),
-        i18n("Previous"),
-        this, SLOT(toolbarRewindPrev()));
-
-    m_action_rewind = addAction(
-        QIcon::fromTheme(_("kwave_player_rew")),
-        i18n("Rewind"),
-        this, SLOT(toolbarRewind()));
-
     m_action_record = addAction(
-        QIcon::fromTheme(_("kwave_player_record")),
+        QIcon::fromTheme(u"media-record"_s),
         i18n("Record"),
-        this, SLOT(toolbarRecord()));
+        this, &Kwave::PlayerToolBar::toolbarRecord);
 
     m_action_play = addAction(
-        QIcon::fromTheme(_("kwave_player_play")),
+        QIcon::fromTheme(u"media-playback-start"_s),
         i18n("Start playback"),
-        this, SLOT(toolbarStart()));
-
-    m_action_loop = addAction(
-        QIcon::fromTheme(_("kwave_player_loop")),
-        i18n("Start playback and loop"),
-        this, SLOT(toolbarLoop()));
+        this, &Kwave::PlayerToolBar::toolbarStart);
 
     m_action_pause = addAction(
-        QIcon::fromTheme(_("kwave_player_pause")),
+        QIcon::fromTheme(u"media-playback-pause"_s),
         QString(),
-        this, SLOT(toolbarPause()));
+        this, &Kwave::PlayerToolBar::toolbarPause);
+    m_action_pause->setCheckable(true);
 
     m_action_stop = addAction(
-        QIcon::fromTheme(_("kwave_player_stop")),
+        QIcon::fromTheme(u"media-playback-stop"_s),
         i18n("Stop playback or loop"),
-        this, SLOT(toolbarStop()));
+        this, &Kwave::PlayerToolBar::toolbarStop);
+
+    m_action_loop = addAction(
+        QIcon::fromTheme(u"media-repeat-all"_s),
+        i18n("Start playback and loop"),
+        this, &Kwave::PlayerToolBar::toolbarLoop);
+
+    m_action_prev = addAction(
+        QIcon::fromTheme(u"media-skip-backward"_s),
+        i18n("Previous"),
+        this, &Kwave::PlayerToolBar::toolbarRewindPrev);
+
+    m_action_rewind = addAction(
+        QIcon::fromTheme(u"media-seek-backward"_s),
+        i18n("Rewind"),
+        this, &Kwave::PlayerToolBar::toolbarRewind);
 
     m_action_forward = addAction(
-        QIcon::fromTheme(_("kwave_player_fwd")),
+        QIcon::fromTheme(u"media-seek-forward"_s),
         i18n("Forward"),
-        this, SLOT(toolbarForward()));
+        this, &Kwave::PlayerToolBar::toolbarForward);
 
     m_action_next = addAction(
-        QIcon::fromTheme(_("kwave_player_end")),
+        QIcon::fromTheme(u"media-skip-forward"_s),
         i18n("Next"),
-        this, SLOT(toolbarForwardNext()));
+        this, &Kwave::PlayerToolBar::toolbarForwardNext);
 
     // initial state update
     updateState();
@@ -124,9 +123,7 @@ Kwave::PlayerToolBar::PlayerToolBar(KMainWindow *parent, const QString &name,
 //***************************************************************************
 Kwave::PlayerToolBar::~PlayerToolBar()
 {
-    if (m_pause_timer) delete m_pause_timer;
-    m_pause_timer = Q_NULLPTR;
-    m_context = Q_NULLPTR;
+    m_context = nullptr;
 }
 
 //***************************************************************************
@@ -136,41 +133,37 @@ void Kwave::PlayerToolBar::contextSwitched(Kwave::FileContext *context)
 
     // disconnect the playback controller of the previous context
     if (m_context && m_playback) {
-        disconnect(m_playback, SIGNAL(sigPlaybackStarted()),
-                   this,       SLOT(updateState()));
-        disconnect(m_playback, SIGNAL(sigPlaybackPaused()),
-                   this,       SLOT(playbackPaused()));
-        disconnect(m_playback, SIGNAL(sigPlaybackStopped()),
-                   this,       SLOT(updateState()));
-        disconnect(m_playback, SIGNAL(sigPlaybackPos(sample_index_t)),
-                   this,       SLOT(updatePlaybackPos(sample_index_t)));
-        disconnect(m_context, SIGNAL(sigVisibleRangeChanged(sample_index_t,
-            sample_index_t, sample_index_t)),
-            this, SLOT(visibleRangeChanged(sample_index_t,
-            sample_index_t, sample_index_t)) );
+        disconnect(m_playback, &Kwave::PlaybackController::sigPlaybackStarted,
+                   this,       &Kwave::PlayerToolBar::updateState);
+        disconnect(m_playback, &Kwave::PlaybackController::sigPlaybackPaused,
+                   this,       &Kwave::PlayerToolBar::updateState);
+        disconnect(m_playback, &Kwave::PlaybackController::sigPlaybackStopped,
+                   this,       &Kwave::PlayerToolBar::updateState);
+        disconnect(m_playback, &Kwave::PlaybackController::sigPlaybackPos,
+                   this,       &Kwave::PlayerToolBar::updatePlaybackPos);
+        disconnect(m_context,  &Kwave::FileContext::sigVisibleRangeChanged,
+                   this,       &Kwave::PlayerToolBar::visibleRangeChanged);
     }
 
     // use the new context
     m_context = context;
 
     Kwave::SignalManager *signal =
-        (m_context) ? m_context->signalManager() : Q_NULLPTR;
-    m_playback = (signal) ? &signal->playbackController() : Q_NULLPTR;
+        (m_context) ? m_context->signalManager() : nullptr;
+    m_playback = (signal) ? &signal->playbackController() : nullptr;
 
     // connect the playback controller of the new context
     if (m_context && m_playback) {
-        connect(m_playback, SIGNAL(sigPlaybackStarted()),
-                this,       SLOT(updateState()));
-        connect(m_playback, SIGNAL(sigPlaybackPaused()),
-                this,       SLOT(playbackPaused()));
-        connect(m_playback, SIGNAL(sigPlaybackStopped()),
-                this,       SLOT(updateState()));
-        connect(m_playback, SIGNAL(sigPlaybackPos(sample_index_t)),
-                this,       SLOT(updatePlaybackPos(sample_index_t)));
-        connect(m_context, SIGNAL(sigVisibleRangeChanged(sample_index_t,
-            sample_index_t, sample_index_t)),
-            this, SLOT(visibleRangeChanged(sample_index_t,
-            sample_index_t, sample_index_t)) );
+        connect(m_playback, &Kwave::PlaybackController::sigPlaybackStarted,
+                this,       &Kwave::PlayerToolBar::updateState);
+        connect(m_playback, &Kwave::PlaybackController::sigPlaybackPaused,
+                this,       &Kwave::PlayerToolBar::updateState);
+        connect(m_playback, &Kwave::PlaybackController::sigPlaybackStopped,
+                this,       &Kwave::PlayerToolBar::updateState);
+        connect(m_playback, &Kwave::PlaybackController::sigPlaybackPos,
+                this,       &Kwave::PlayerToolBar::updatePlaybackPos);
+        connect(m_context,  &Kwave::FileContext::sigVisibleRangeChanged,
+                this,       &Kwave::PlayerToolBar::visibleRangeChanged);
     }
 
     updateState();
@@ -180,7 +173,7 @@ void Kwave::PlayerToolBar::contextSwitched(Kwave::FileContext *context)
 void Kwave::PlayerToolBar::contextDestroyed(Kwave::FileContext *context)
 {
     if (context != m_context) return; // not of interest
-    contextSwitched(Q_NULLPTR);
+    contextSwitched(nullptr);
 }
 
 //***************************************************************************
@@ -207,7 +200,7 @@ void Kwave::PlayerToolBar::toolbarRewindPrev()
         if (prev < first) prev = first;
         m_playback->seekTo(prev);
     } else {
-        emit sigCommand(_("view:scroll_prev_label()"));
+        emit sigCommand(u"view:scroll_prev_label()"_s);
     }
 }
 
@@ -239,7 +232,7 @@ void Kwave::PlayerToolBar::toolbarRewind()
 
         m_playback->seekTo(pos);
     } else {
-        emit sigCommand(_("view:scroll_left()"));
+        emit sigCommand(u"view:scroll_left()"_s);
     }
 }
 
@@ -248,7 +241,7 @@ void Kwave::PlayerToolBar::toolbarRecord()
 {
     if (!m_action_record || !m_action_record->isEnabled()) return;
 
-    emit sigCommand(_("plugin(record)"));
+    emit sigCommand(u"plugin(record)"_s);
 }
 
 //***************************************************************************
@@ -263,24 +256,6 @@ void Kwave::PlayerToolBar::toolbarLoop()
     if (m_playback) m_playback->playbackLoop();
 }
 
-//***************************************************************************
-void Kwave::PlayerToolBar::playbackPaused()
-{
-    updateState();
-
-    if (!m_pause_timer) {
-        m_pause_timer = new(std::nothrow) QTimer(this);
-        Q_ASSERT(m_pause_timer);
-        if (!m_pause_timer) return;
-
-        m_blink_on = true;
-        m_pause_timer->start(500);
-        connect(m_pause_timer, SIGNAL(timeout()),
-                this, SLOT(blinkPause()));
-        blinkPause();
-    }
-}
-
 //***************************************************************************
 void Kwave::PlayerToolBar::toolbarPause()
 {
@@ -304,20 +279,6 @@ void Kwave::PlayerToolBar::toolbarStop()
     if (m_playback) m_playback->playbackStop();
 }
 
-//***************************************************************************
-void Kwave::PlayerToolBar::blinkPause()
-{
-    const bool paused = m_playback && m_playback->paused();
-
-    Q_ASSERT(m_action_pause);
-    if (!m_action_pause) return;
-
-    m_action_pause->setIcon(QIcon::fromTheme(_((paused && m_blink_on) ?
-        "kwave_player_pause_2" : "kwave_player_pause")));
-
-    m_blink_on = !m_blink_on;
-}
-
 //***************************************************************************
 void Kwave::PlayerToolBar::toolbarForward()
 {
@@ -346,7 +307,7 @@ void Kwave::PlayerToolBar::toolbarForward()
 
         m_playback->seekTo(pos);
     } else {
-        emit sigCommand(_("view:scroll_right()"));
+        emit sigCommand(u"view:scroll_right()"_s);
     }
 }
 
@@ -363,7 +324,7 @@ void Kwave::PlayerToolBar::toolbarForwardNext()
             next = m_playback->startPos(); // wrap around to start
         m_playback->seekTo(next);
     } else {
-        emit sigCommand(_("view:scroll_next_label()"));
+        emit sigCommand(u"view:scroll_next_label()"_s);
     }
 }
 
@@ -407,30 +368,30 @@ void Kwave::PlayerToolBar::updateState()
         UPDATE_MENU(next,   "ID_PLAYBACK_NEXT");
 
         // scroll controls per menu
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_START"), false);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_END"),   false);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_PREV"),  false);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_NEXT"),  false);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_RIGHT"), false);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_LEFT"),  false);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_START"_s, false);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_END"_s,   false);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_PREV"_s,  false);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_NEXT"_s,  false);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_RIGHT"_s, false);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_LEFT"_s,  false);
     } else {
         // seek buttons in normal mode
         m_action_prev->setEnabled(    have_signal && !at_start);
         m_action_rewind->setEnabled(  have_signal && !at_start);
         m_action_forward->setEnabled( have_signal && !at_end);
         m_action_next->setEnabled(    have_signal && !at_end);
-        m_menu_manager.setItemEnabled(_("ID_PLAYBACK_PREV"),    false);
-        m_menu_manager.setItemEnabled(_("ID_PLAYBACK_REWIND"),  false);
-        m_menu_manager.setItemEnabled(_("ID_PLAYBACK_FORWARD"), false);
-        m_menu_manager.setItemEnabled(_("ID_PLAYBACK_NEXT"),    false);
+        m_menu_manager.setItemEnabled(u"ID_PLAYBACK_PREV"_s,    false);
+        m_menu_manager.setItemEnabled(u"ID_PLAYBACK_REWIND"_s,  false);
+        m_menu_manager.setItemEnabled(u"ID_PLAYBACK_FORWARD"_s, false);
+        m_menu_manager.setItemEnabled(u"ID_PLAYBACK_NEXT"_s,    false);
 
         // scroll controls per menu
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_START"), !at_start);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_END"),   !at_end);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_PREV"),  !at_start);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_NEXT"),  !at_end);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_RIGHT"), !at_end);
-        m_menu_manager.setItemEnabled(_("ID_SCROLL_LEFT"),  !at_start);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_START"_s, !at_start);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_END"_s,   !at_end);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_PREV"_s,  !at_start);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_NEXT"_s,  !at_end);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_RIGHT"_s, !at_end);
+        m_menu_manager.setItemEnabled(u"ID_SCROLL_LEFT"_s,  !at_start);
     }
 
     /* --- standard record/playback controls --- */
@@ -443,26 +404,16 @@ void Kwave::PlayerToolBar::updateState()
     UPDATE_MENU(play,   "ID_PLAYBACK_START");
     UPDATE_MENU(loop,   "ID_PLAYBACK_LOOP");
     UPDATE_MENU(stop,   "ID_PLAYBACK_STOP");
-    m_menu_manager.setItemEnabled(_("ID_PLAYBACK_PAUSE"),    playing);
-    m_menu_manager.setItemEnabled(_("ID_PLAYBACK_CONTINUE"), paused);
-
-    /* handling of blink timer */
-    if (m_pause_timer && !paused) {
-        // stop blinking
-        m_pause_timer->stop();
-        delete m_pause_timer;
-        m_pause_timer = Q_NULLPTR;
-
-        m_blink_on = false;
-        blinkPause();
-        m_blink_on = false;
-    }
+    m_menu_manager.setItemEnabled(u"ID_PLAYBACK_PAUSE"_s,    playing);
+    m_menu_manager.setItemEnabled(u"ID_PLAYBACK_CONTINUE"_s, paused);
 
     /* pause button: continue/pause playback */
     if (paused) {
         m_action_pause->setToolTip(i18n("Continue playback"));
+        m_action_pause->setChecked(true);
     } else {
         m_action_pause->setToolTip(i18n("Pause playback"));
+        m_action_pause->setChecked(false);
     }
 
 }
@@ -545,3 +496,5 @@ void Kwave::PlayerToolBar::visibleRangeChanged(sample_index_t offset,
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_PlayerToolBar.cpp"
