@@ -19,6 +19,7 @@
 #define CURVE_WIDGET_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QMenu>
@@ -34,7 +35,7 @@ class QString;
 
 namespace Kwave
 {
-    class Q_DECL_EXPORT CurveWidget: public QWidget
+    class LIBKWAVEGUI_EXPORT CurveWidget: public QWidget
     {
         Q_OBJECT
     public:
@@ -43,7 +44,7 @@ namespace Kwave
         explicit CurveWidget(QWidget *parent);
 
         /** Destructor */
-        virtual ~CurveWidget() Q_DECL_OVERRIDE;
+        ~CurveWidget() override;
 
         /** Returns a command string for the curve. */
         QString getCommand();
@@ -114,10 +115,10 @@ namespace Kwave
 
     protected slots:
 
-        virtual void mousePressEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
-        virtual void mouseReleaseEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
-        virtual void mouseMoveEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
-        virtual void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+        void mousePressEvent(QMouseEvent * ) override;
+        void mouseReleaseEvent(QMouseEvent * ) override;
+        void mouseMoveEvent(QMouseEvent * ) override;
+        void paintEvent(QPaintEvent *) override;
 
     protected:
 
@@ -139,13 +140,13 @@ namespace Kwave
         Kwave::Curve m_curve;
 
         /** Popup (context) menu for the right mouse button */
-        QMenu *m_menu;
+        QMenu *m_menu = nullptr;
 
         /**
          * Part of the popup (context) menu for the right
          * mouse button with the list of preset files
          */
-        QMenu *m_preset_menu;
+        QMenu *m_preset_menu = nullptr;
 
         /** Currently selected point or null if none selected */
         Kwave::Curve::Point m_current;
