@@ -15,10 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <QCursor>
-#include <QImage>
 #include <QMouseEvent>
 #include <QTransform>
 
@@ -138,3 +136,5 @@ void Kwave::ImageView::paintEvent(QPaintEvent *)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_ImageView.cpp"
