@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <QObject>
 #include <QWidget>
@@ -79,3 +78,5 @@ void Kwave::InvertableSpinBox::stepDown()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_InvertableSpinBox.cpp"
