@@ -15,11 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <new>
 
-#include <QtGlobal>
 #include <QIcon>
 #include <QMenu>
 #include <QPainter>
@@ -78,7 +76,7 @@ Kwave::TrackView::TrackView(QWidget *parent, QWidget *controls,
         if (!layout) return;
 
         Kwave::MultiStateWidget *msw =
-            new(std::nothrow) Kwave::MultiStateWidget(Q_NULLPTR, 0);
+            new(std::nothrow) Kwave::MultiStateWidget(nullptr, 0);
         Q_ASSERT(msw);
         if (!msw) {
             delete layout;
@@ -176,7 +174,7 @@ void Kwave::TrackView::setVerticalZoom(double zoom)
 QSharedPointer<Kwave::ViewItem> Kwave::TrackView::findItem(const QPoint &pos)
 {
     QSharedPointer<Kwave::ViewItem> item =
-        QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
+        QSharedPointer<Kwave::ViewItem>(nullptr);
     Q_ASSERT(m_signal_manager);
     if (!m_signal_manager) return item;
 
@@ -265,7 +263,7 @@ QSharedPointer<Kwave::ViewItem> Kwave::TrackView::findItem(const QPoint &pos)
     }
 
     // nothing found
-    return QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
+    return QSharedPointer<Kwave::ViewItem>(nullptr);
 }
 
 //***************************************************************************
@@ -528,3 +526,5 @@ void Kwave::TrackView::showCursor(sample_index_t pos)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_TrackView.cpp"
