@@ -19,6 +19,7 @@
 #define MULTI_PLAYBACK_SINK_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QBitArray>
@@ -33,7 +34,7 @@
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT MultiPlaybackSink
+    class LIBKWAVE_EXPORT MultiPlaybackSink
         :public Kwave::MultiTrackSink<Kwave::PlaybackSink, false>
     {
         Q_OBJECT
@@ -46,7 +47,7 @@ namespace Kwave
         MultiPlaybackSink(unsigned int tracks, Kwave::PlayBackDevice *device);
 
         /** Destructor */
-        virtual ~MultiPlaybackSink();
+        virtual ~MultiPlaybackSink() override;
 
     private slots:
 
