@@ -20,6 +20,7 @@
 #define MULTI_WRITER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -35,7 +36,7 @@ namespace Kwave
      * A MultiWriter encapsulates a set of <c>Writer</c>s for
      * easier use of multi-track signals.
      */
-    class Q_DECL_EXPORT MultiWriter
+    class LIBKWAVE_EXPORT MultiWriter
         :public Kwave::MultiTrackSink<Kwave::Writer, false>
     {
         Q_OBJECT
@@ -45,7 +46,7 @@ namespace Kwave
         MultiWriter();
 
         /** Destructor */
-        virtual ~MultiWriter() Q_DECL_OVERRIDE;
+        ~MultiWriter() override;
 
         /** Returns the last sample index of all streams */
         virtual sample_index_t last() const;
@@ -54,11 +55,11 @@ namespace Kwave
         virtual void flush();
 
         /** @see Kwave::MultiTrackSink<Kwave::Writer>::clear() */
-        virtual void clear() Q_DECL_OVERRIDE;
+        void clear() override;
 
         /** @see Kwave::MultiTrackSink<Kwave::Writer>::insert() */
         virtual bool insert(unsigned int track, Kwave::Writer *writer)
-            Q_DECL_OVERRIDE;
+            override;
 
     signals:
 
