@@ -46,25 +46,25 @@ namespace Kwave
         UndoInsertTrack(Kwave::Signal &signal, unsigned int track);
 
         /** Destructor */
-        virtual ~UndoInsertTrack() Q_DECL_OVERRIDE;
+        ~UndoInsertTrack() override;
 
         /**
          * Returns a verbose short description of the action.
          */
-        virtual QString description() Q_DECL_OVERRIDE;
+        QString description() override;
 
         /** @see UndoAction::undoSize() */
-        virtual qint64 undoSize() Q_DECL_OVERRIDE;
+        qint64 undoSize() override;
 
         /** @see UndoAction::redoSize() */
-        virtual qint64 redoSize() Q_DECL_OVERRIDE;
+        qint64 redoSize() override;
 
         /** @see UndoAction::store() */
-        virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+        bool store(Kwave::SignalManager &manager) override;
 
         /** @see UndoAction::undo() */
-        virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
-                                        bool with_redo) Q_DECL_OVERRIDE;
+        Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+                                        bool with_redo) override;
 
     protected:
 
