@@ -35,12 +35,12 @@
 #include "logo.xpm"
 
 /** increment value of the "h" channel of the color of the sine waves */
-#define COLOR_INCREMENT (static_cast<double>(0.001))
+#define COLOR_INCREMENT (0.001f)
 
 //***************************************************************************
 Kwave::LogoWidget::LogoWidget(QWidget *parent)
     :QWidget(parent), m_width(-1), m_height(-1), m_repaint(false),
-     m_image(Q_NULLPTR), m_logo(xpm_aboutlogo), m_timer(Q_NULLPTR),
+     m_image(nullptr), m_logo(xpm_aboutlogo), m_timer(nullptr),
      m_color_h(0.0)
 {
     for (int i = 0; i < MAXSIN; m_deg[i++] = 0) {}
@@ -80,8 +80,8 @@ void Kwave::LogoWidget::doAnim()
 //***************************************************************************
 Kwave::LogoWidget::~LogoWidget()
 {
-    if (m_timer) delete m_timer;
-    if (m_image) delete m_image;
+    delete m_timer;
+    delete m_image;
 }
 
 //***************************************************************************
@@ -122,9 +122,9 @@ void Kwave::LogoWidget::paintEvent(QPaintEvent *)
 
         // draw the sine waves with XOR
         p.setCompositionMode(QPainter::CompositionMode_Exclusion);
-        p.setBrush(QColor::fromHsvF(m_color_h, 1.0, 1.0));
+        p.setBrush(QColor::fromHsvF(m_color_h, 1.0f, 1.0f));
         m_color_h += COLOR_INCREMENT; // this gives the nice color change :-)
-        if (m_color_h > 1.0) m_color_h -= 1.0;
+        if (m_color_h > 1.0f) m_color_h -= 1.0f;
 
         double amp = sin(m_deg[MAXSIN - 1] * 3);
         for (int j = 0; j < MAXSIN; j++) {
@@ -153,3 +153,5 @@ void Kwave::LogoWidget::paintEvent(QPaintEvent *)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_LogoWidget.cpp"
