@@ -95,7 +95,7 @@ QStringList *Kwave::AmplifyFreePlugin::setup(QStringList &previous_params)
     QPointer<Kwave::AmplifyFreeDialog> dialog =
         new(std::nothrow) Kwave::AmplifyFreeDialog(parentWidget());
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     // remove the first list entry (action name), the rest is for the dialog
     if ((m_params.count() > 2) && !(m_params.count() & 1)) {
@@ -117,11 +117,11 @@ QStringList *Kwave::AmplifyFreePlugin::setup(QStringList &previous_params)
         emitCommand(cmd);
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
@@ -149,7 +149,7 @@ void Kwave::AmplifyFreePlugin::run(QStringList params)
     Kwave::UndoTransactionGuard undo_guard(*this, m_action_name);
 
     sample_index_t input_length = selection(&track_list, &first, &last, true);
-    unsigned int   tracks       = track_list.count();
+    unsigned int   tracks = static_cast<unsigned int>(track_list.count());
 
     // create all objects
     Kwave::MultiTrackReader source(Kwave::SinglePassForward,
@@ -195,3 +195,5 @@ void Kwave::AmplifyFreePlugin::run(QStringList params)
 #include "AmplifyFreePlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_AmplifyFreePlugin.cpp"
