@@ -71,12 +71,12 @@ Kwave::RecordPlugin::RecordPlugin(QObject *parent, const QVariantList &args)
      m_device_name(),
      m_controller(),
      m_state(Kwave::REC_EMPTY),
-     m_device(Q_NULLPTR),
-     m_dialog(Q_NULLPTR),
-     m_thread(Q_NULLPTR),
-     m_decoder(Q_NULLPTR),
+     m_device(nullptr),
+     m_dialog(nullptr),
+     m_thread(nullptr),
+     m_decoder(nullptr),
      m_prerecording_queue(),
-     m_writers(Q_NULLPTR),
+     m_writers(nullptr),
      m_buffers_recorded(0),
      m_inhibit_count(0),
      m_trigger_value(),
@@ -93,19 +93,19 @@ Kwave::RecordPlugin::RecordPlugin(QObject *parent, const QVariantList &args)
 Kwave::RecordPlugin::~RecordPlugin()
 {
     Q_ASSERT(!m_dialog);
-    if (m_dialog) delete m_dialog;
-    m_dialog = Q_NULLPTR;
+    delete m_dialog;
+    m_dialog = nullptr;
 
     Q_ASSERT(!m_thread);
-    if (m_thread) delete m_thread;
-    m_thread = Q_NULLPTR;
+    delete m_thread;
+    m_thread = nullptr;
 
     Q_ASSERT(!m_decoder);
-    if (m_decoder) delete m_decoder;
-    m_decoder = Q_NULLPTR;
+    delete m_decoder;
+    m_decoder = nullptr;
 
-    if (m_device) delete m_device;
-    m_device = Q_NULLPTR;
+    delete m_device;
+    m_device = nullptr;
 }
 
 //***************************************************************************
@@ -138,15 +138,15 @@ QStringList *Kwave::RecordPlugin::setup(QStringList &previous_params)
         parentWidget(), previous_params, &m_controller, mode
     );
     Q_ASSERT(m_dialog);
-    if (!m_dialog) return Q_NULLPTR;
+    if (!m_dialog) return nullptr;
 
     // create the lowlevel recording thread
     m_thread = new(std::nothrow) Kwave::RecordThread();
     Q_ASSERT(m_thread);
     if (!m_thread) {
         delete m_dialog;
-        m_dialog = Q_NULLPTR;
-        return Q_NULLPTR;
+        m_dialog = nullptr;
+        return nullptr;
     }
 
     // connect some signals of the setup dialog
@@ -223,8 +223,8 @@ QStringList *Kwave::RecordPlugin::setup(QStringList &previous_params)
         *list = m_dialog->params().toList();
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
     /* de-queue all buffers that are pending and remove the record thread */
@@ -233,14 +233,14 @@ QStringList *Kwave::RecordPlugin::setup(QStringList &previous_params)
         while (m_thread->queuedBuffers())
             processBuffer();
         delete m_thread;
-        m_thread = Q_NULLPTR;
+        m_thread = nullptr;
     }
 
-    if (m_decoder) delete m_decoder;
-    m_decoder = Q_NULLPTR;
+    delete m_decoder;
+    m_decoder = nullptr;
 
     delete m_dialog;
-    m_dialog = Q_NULLPTR;
+    m_dialog = nullptr;
 
     // flush away all prerecording buffers
     m_prerecording_queue.clear();
@@ -267,7 +267,7 @@ void Kwave::RecordPlugin::closeDevice()
     if (m_device) {
         m_device->close();
         delete m_device;
-        m_device = Q_NULLPTR;
+        m_device = nullptr;
     }
 }
 
@@ -282,8 +282,8 @@ void Kwave::RecordPlugin::setMethod(Kwave::record_method_t method)
 
     // change the recording method (class RecordDevice)
     if ((method != m_method) || !m_device) {
-        if (m_device) delete m_device;
-        m_device = Q_NULLPTR;
+        delete m_device;
+        m_device = nullptr;
         bool searching = false;
 
         // use the previous device
@@ -927,8 +927,8 @@ void Kwave::RecordPlugin::setupRecordThread()
     Q_ASSERT(!m_thread->isRunning());
 
     // delete the previous decoder
-    if (m_decoder) delete m_decoder;
-    m_decoder = Q_NULLPTR;
+    delete m_decoder;
+    m_decoder = nullptr;
 
     // our own reference to the record parameters
     const Kwave::RecordParams &params = m_dialog->params();
@@ -1043,7 +1043,7 @@ void Kwave::RecordPlugin::startRecording()
             signalManager().disableUndo();
 
             // create a sink for our audio data
-            if (m_writers) delete m_writers;
+            delete m_writers;
             m_writers = new(std::nothrow) Kwave::MultiTrackWriter(
                 signalManager(), Kwave::Append);
             if ((!m_writers) || (m_writers->tracks() != tracks)) {
@@ -1139,7 +1139,7 @@ void Kwave::RecordPlugin::stateChanged(Kwave::RecordState state)
             if (m_writers) {
                 m_writers->flush();
                 delete m_writers;
-                m_writers = Q_NULLPTR;
+                m_writers = nullptr;
             }
             m_buffers_recorded = 0;
             m_dialog->updateBufferState(0, 0);
@@ -1188,7 +1188,8 @@ void Kwave::RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
                                 unsigned int track,
                                 unsigned int tracks)
 {
-    unsigned int samples = raw_data.size() / bytes_per_sample / tracks;
+    unsigned int raw_data_size = static_cast<unsigned int>(raw_data.size());
+    unsigned int samples = (raw_data_size / bytes_per_sample) / tracks;
 
 #if 0
     // simple sawtooth generator, based on raw data
@@ -1489,7 +1490,8 @@ void Kwave::RecordPlugin::processBuffer()
     Q_ASSERT(bytes_per_sample);
     if (!bytes_per_sample) return;
 
-    unsigned int samples = (buffer.size() / bytes_per_sample) / tracks;
+    unsigned int buffer_size = static_cast<unsigned int>(buffer.size());
+    unsigned int samples = (buffer_size / bytes_per_sample) / tracks;
     Q_ASSERT(samples);
     if (!samples) return;
 
@@ -1592,6 +1594,7 @@ void Kwave::RecordPlugin::processBuffer()
 
                 break;
             }
+            DEFAULT_IMPOSSIBLE;
         }
     }
 
@@ -1619,3 +1622,5 @@ void Kwave::RecordPlugin::prerecordingChanged(bool enable)
 #include "RecordPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_RecordPlugin.cpp"
