@@ -164,7 +164,7 @@ void Kwave::SampleRatePlugin::run(QStringList params)
 
     // create the converter
     Kwave::MultiTrackSource<Kwave::RateConverter, true> converter(
-        tracks.count(), this);
+        static_cast<unsigned int>(tracks.count()), this);
     converter.setAttribute(SLOT(setRatio(QVariant)), QVariant(ratio));
 
     // create the writer with the appropriate length
@@ -217,7 +217,7 @@ void Kwave::SampleRatePlugin::run(QStringList params)
     }
 
     // update the selection if it was not empty
-    length = selection(Q_NULLPTR, &first, &last, false);
+    length = selection(nullptr, &first, &last, false);
     if (length) {
         if (m_whole_signal) {
             // if whole signal selected -> adjust start and end
@@ -245,3 +245,5 @@ void Kwave::SampleRatePlugin::run(QStringList params)
 #include "SampleRatePlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_SampleRatePlugin.cpp"
