@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: 2007 Thomas Eschenbacher <Thomas.Eschenbacher@gmx.de>
+// SPDX-FileCopyrightText: 2024 Mark Penner <mrp@markpenner.space>
+// SPDX-License-Identifier: GPL-2.0-or-later
 /***************************************************************************
    SaveBlocksPlugin.cpp  -  Plugin for saving blocks between labels
                              -------------------
@@ -43,6 +46,8 @@
 #include "SaveBlocksDialog.h"
 #include "SaveBlocksPlugin.h"
 
+using namespace Qt::StringLiterals;
+
 KWAVE_PLUGIN(saveblocks, SaveBlocksPlugin)
 
 //***************************************************************************
@@ -77,17 +82,14 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
                          (selection_right + 1 >= signalLength()));
     bool enable_selection_only = selected_something && !selected_all;
 
-    QString filename = m_url.path();
-    QString base = findBase(filename, m_pattern);
+    QString base = findBase(m_url.path(), m_pattern);
     scanBlocksToSave(base, m_selection_only && enable_selection_only);
 
-    QPointer<Kwave::SaveBlocksDialog> dialog =
-        new(std::nothrow) Kwave::SaveBlocksDialog(
-            _("kfiledialog:///kwave_save_blocks"),
-            Kwave::CodecManager::encodingFilter(),
+    QUrl signalname = Kwave::URLfromUserInput(signalName());
+
+    Kwave::SaveBlocksDialog *dialog = new Kwave::SaveBlocksDialog(
             parentWidget(),
-            Kwave::URLfromUserInput(signalName()),
-            _("*.wav"),
+            signalname,
             m_pattern,
             m_numbering_mode,
             m_selection_only,
@@ -96,62 +98,55 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
         if (!dialog) return nullptr;
 
     // connect the signals/slots from the plugin and the dialog
-    connect(dialog, SIGNAL(sigSelectionChanged(QString,
-        QString,Kwave::SaveBlocksPlugin::numbering_mode_t,bool)),
-        this, SLOT(updateExample(QString,QString,
-        Kwave::SaveBlocksPlugin::numbering_mode_t,bool)));
-    connect(this, SIGNAL(sigNewExample(QString)),
-        dialog, SLOT(setNewExample(QString)));
+    connect(dialog, &SaveBlocksDialog::sigSelectionChanged,
+        this, &SaveBlocksPlugin::updateExample);
+    connect(this, &SaveBlocksPlugin::sigNewExample,
+        dialog, &SaveBlocksDialog::setNewExample);
 
     dialog->setWindowTitle(description());
     dialog->emitUpdate();
     if ((dialog->exec() != QDialog::Accepted) || !dialog) {
-        delete dialog;
         return nullptr;
     }
 
+    QUrl url = dialog->selectedUrl();
+    if (url.isEmpty()) {
+        return nullptr;
+    }
+    QString name = url.path();
+
+    QString filename = signalname.fileName();
+    QFileInfo path(filename);
+
+    // replace the current extension with the selected extension
+    QString old_ext = path.suffix();
+    if (old_ext.length()) filename.remove(old_ext);
+    QString ext = Kwave::Parser::escape(dialog->extension());
+    filename += ext.mid(1);
+    name += u"/"_s + filename;
+
+    name = Kwave::Parser::escape(name);
+    QString pattern = Kwave::Parser::escape(dialog->pattern());
+    int mode = static_cast<int>(dialog->numberingMode());
+    bool selection_only = (enable_selection_only) ?
+        dialog->selectionOnly() : m_selection_only;
+
     QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
-    if (list) {
-        // user has pressed "OK"
-        QString pattern;
-
-        QUrl url = dialog->selectedUrl();
-        if (url.isEmpty()) {
-            delete dialog;
-            delete list;
-            return nullptr;
-        }
-        QString name = url.path();
-        QFileInfo path(name);
-
-        // add the correct extension if necessary
-        if (!path.suffix().length()) {
-            QString ext = dialog->selectedExtension();
-            QStringList extensions = ext.split(_(" "));
-            ext = extensions.first();
-            name += ext.mid(1);
-        }
-
-        name     = Kwave::Parser::escape(name);
-        pattern  = Kwave::Parser::escape(dialog->pattern());
-        int mode = static_cast<int>(dialog->numberingMode());
-        bool selection_only = (enable_selection_only) ?
-            dialog->selectionOnly() : m_selection_only;
-
-        *list << name;
-        *list << pattern;
-        *list << QString::number(mode);
-        *list << QString::number(selection_only);
-
-        emitCommand(_("plugin:execute(saveblocks,") +
-            name + _(",") + pattern + _(",") +
-            QString::number(mode) + _(",") +
-            QString::number(selection_only) + _(")")
-        );
+    if (!list) {
+        return nullptr;
     }
+    *list << name;
+    *list << pattern;
+    *list << QString::number(mode);
+    *list << QString::number(selection_only);
+
+    emitCommand(u"plugin:execute(saveblocks,"_s +
+        name + u","_s + pattern + u","_s +
+        QString::number(mode) + u","_s +
+        QString::number(selection_only) + u")"_s
+    );
 
-    delete dialog;
     return list;
 }
 
@@ -217,8 +212,8 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
     unsigned int first = firstIndex(path, base, ext, m_pattern,
                                     m_numbering_mode, count);
 
-//     qDebug("m_url            = '%s'", m_url.prettyURL().local8Bit().data());
-//     qDebug("m_pattern        = '%s'", m_pattern.local8Bit().data());
+//     qDebug("m_url            = '%s'", m_url.toDisplayString().toLocal8Bit().data());
+//     qDebug("m_pattern        = '%s'", m_pattern.toLocal8Bit().data());
 //     qDebug("m_numbering_mode = %d", (int)m_numbering_mode);
 //     qDebug("selection_only   = %d", selection_only);
 //     qDebug("indices          = %u...%u (count=%u)", first,
@@ -303,7 +298,6 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
         foreach (const QString &missing, missing_dirs) {
             QUrl url(base_url);
             url.setPath(
-                base_url.path(QUrl::FullyEncoded) +
                 QString::fromLatin1(QUrl::toPercentEncoding(missing)),
                 QUrl::StrictMode
             );
@@ -513,7 +507,7 @@ QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
         QString ex = _("(\\\\\\[\\\\") + format + _("nr\\\\\\])");
         QRegularExpression rx(ex, QRegularExpression::CaseInsensitiveOption);
         format += _("u");
-        p.replace(rx, nr.asprintf(format.toLatin1(), index));
+        p.replace(rx, nr.asprintf(format.toLatin1().constData(), index));
     }
 
     // format the "count" parameter
@@ -529,7 +523,7 @@ QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
             QRegularExpression rx(ex,
                 QRegularExpression::CaseInsensitiveOption);
             format += _("u");
-            p.replace(rx, nr.asprintf(format.toLatin1(), count));
+            p.replace(rx, nr.asprintf(format.toLatin1().constData(), count));
         } else {
             p.replace(rx_count, _("(\\d+)"));
         }
@@ -548,7 +542,7 @@ QString Kwave::SaveBlocksPlugin::createFileName(const QString &base,
             QRegularExpression rx(ex,
                                   QRegularExpression::CaseInsensitiveOption);
             format += _("u");
-            p.replace(rx, nr.asprintf(format.toLatin1(), total));
+            p.replace(rx, nr.asprintf(format.toLatin1().constData(), total));
         } else {
             p.replace(rx_total, _("(\\d+)"));
         }
@@ -735,12 +729,14 @@ QString Kwave::SaveBlocksPlugin::findBase(const QString &filename,
 
 //***************************************************************************
 QString Kwave::SaveBlocksPlugin::firstFileName(const QString &filename,
-    const QString &pattern, Kwave::SaveBlocksPlugin::numbering_mode_t mode,
-    bool selection_only)
+                                               const QString &pattern,
+                                               Kwave::SaveBlocksPlugin::numbering_mode_t mode,
+                                               const QString &extension,
+                                               bool selection_only)
 {
     QFileInfo file(filename);
     QString path = file.absolutePath();
-    QString ext  = file.suffix();
+    QString ext  = extension.mid(1);
     QString base = findBase(filename, pattern);
 
     // now we have a new name, base and extension
@@ -756,10 +752,12 @@ QString Kwave::SaveBlocksPlugin::firstFileName(const QString &filename,
 
 //***************************************************************************
 void Kwave::SaveBlocksPlugin::updateExample(const QString &filename,
-    const QString &pattern, Kwave::SaveBlocksPlugin::numbering_mode_t mode,
-    bool selection_only)
+                                            const QString &pattern,
+                                            Kwave::SaveBlocksPlugin::numbering_mode_t mode,
+                                            const QString &extension,
+                                            bool selection_only)
 {
-    QString example = firstFileName(filename, pattern, mode, selection_only);
+    QString example = firstFileName(filename, pattern, mode, extension, selection_only);
     emit sigNewExample(Kwave::Parser::unescape(example));
 }
 
